@@ -62,6 +62,19 @@ class CommonData
 	public static $REBOOTT_EXE = "rebootTimer.php";
 	public static $REBOOTT_CONFIG = "/icpdas/rebootTimer/rebootTimer.ini";
 
+	//rebootTimer
+	public static $WDTREFRESH_DIR = "/icpdas/wdtRefresh";
+	public static $WDTREFRESH_EXE = "wdtRefresh.php";
+
+	//RTU Client
+	public static $RTUC_DIR = "/icpdas/rtuc";
+	public static $RTUC_EXE = "rtuc.py";
+	public static $RTUC_CONFIG = "/icpdas/rtuc/rtuc.ini";
+
+	//NTP Client
+	public static $NTPC_DIR = "/icpdas/ntpc";
+	public static $NTPC_EXE = "ntpc.php";
+	public static $NTPC_CONFIG = "/icpdas/ntpc/ntpc.ini";
 }
 
 //== get or set interface information from "/etc/network/interfaces"
@@ -195,84 +208,6 @@ function setDNS(&$DNS)
 	file_put_contents(CommonData::$DNS_SETTING_PATH,$data);
 }
 
-//== get DHCPD configuration
-function getDhcpdCfg(&$dhcpdInfo)
-{
-	//get dhcpd config
-	$info = file_get_contents(CommonData::$DHCPD_SETTING_FILE);
-	$info_array = explode("\n", $info);
-
-	$info = strstr($info, "subnet");
-	strtok($info, " ");
-	$dhcpdInfo["subnet"] = strtok(" ");
-
-	$info = strstr($info, "netmask");
-	strtok($info, " ");
-	$dhcpdInfo["netmask"] = strtok(" ");
-
-	$info = strstr($info, "default-lease-time");
-	strtok($info, " ");
-	$dhcpdInfo["default-lease-time"] = strtok(";");
-
-	$info = strstr($info, "max-lease-time");
-	strtok($info, " ");
-	$dhcpdInfo["max-lease-time"] = strtok(";");
-
-	$info = strstr($info, "domain-name-servers");
-	strtok($info, " ");
-	$dhcpdInfo["domain-name-servers"] = strtok(";");
-
-	$info = strstr($info, "broadcast-address");
-	strtok($info, " ");
-	$dhcpdInfo["broadcast-address"] = strtok(";");
-
-	$info = strstr($info, "routers");
-	strtok($info, " ");
-	$dhcpdInfo["routers"] = strtok(";");
-
-	$info = strstr($info, "range");
-	strtok($info, " ");
-	$dhcpdInfo["range_from"] = strtok(" ");
-	$dhcpdInfo["range_to"] = strtok(";");
-
-	//check Start sh in "/etc/init.d/"
-	if(file_exists("/etc/init.d/S" .CommonData::$DHCPD_RUN_SCRIPT))
-		$dhcpdInfo["enable"]="enable";
-	else
-		$dhcpdInfo["enable"]="disable";
-}
-
-//== set DHCPD configuration
-function setDhcpdCfg($dhcpdInfo)
-{
-	//set dhcpd config
-	$new_info = "ddns-update-style none;\n\n";
-	$new_info .= "subnet " .$dhcpdInfo["subnet"] ." netmask " .$dhcpdInfo["netmask"] ." {\n";
-	$new_info .= "\t" ."default-lease-time " .$dhcpdInfo["default-lease-time"] .";\n";
-	$new_info .= "\t" ."max-lease-time " .$dhcpdInfo["max-lease-time"] .";\n";
-	$new_info .= "\t" ."option domain-name-servers " .$dhcpdInfo["domain-name-servers"] .";\n";
-	$new_info .= "\t" ."option broadcast-address " .$dhcpdInfo["broadcast-address"] .";\n";
-	$new_info .= "\t" ."option routers " .$dhcpdInfo["routers"] .";\n";
-	$new_info .= "\t" ."range " .$dhcpdInfo["range_from"] ." " .$dhcpdInfo["range_to"] ."; }\n";
-	$new_info .= "\n";
-
-	file_put_contents(CommonData::$DHCPD_SETTING_FILE, $new_info);
-
-	//set Start sh in "/etc/init.d/"
-	if($dhcpdInfo["enable"]=="enable")
-	{
-		if(!file_exists("/etc/init.d/S" .CommonData::$DHCPD_RUN_SCRIPT))
-		{
-			rename("/etc/init.d/K" .CommonData::$DHCPD_RUN_SCRIPT, "/etc/init.d/S" .CommonData::$DHCPD_RUN_SCRIPT);
-		}
-	}else
-	{
-		if(file_exists("/etc/init.d/S" .CommonData::$DHCPD_RUN_SCRIPT))
-		{
-			rename("/etc/init.d/S" .CommonData::$DHCPD_RUN_SCRIPT, "/etc/init.d/K" .CommonData::$DHCPD_RUN_SCRIPT);
-		}
-	}
-}
 
 //== get PIN code from Modem configure file
 function getPINCode(&$cpin)
@@ -494,102 +429,6 @@ function setpppdRule($enable)
 	file_put_contents(CommonData::$PPPD_UDEV_FILE, $data);
 }
 
-//== get DDNS configure
-function getddnsCfg(&$server, &$domain, &$uname, &$upwd, &$period, &$enable)
-{
-	$data=file_get_contents(CommonData::$DDNS_SETTING_FILE);
-	$array_data=explode("\n",$data);
-
-	foreach ($array_data as $index =>$line)
-	{
-		$line=trim($line);
-		if($line[0]=='#') continue;
-
-		if(($pos=strpos($line, "dyndns_system")) !== false)
-		{
-			$server = trim(substr($line, $pos+13));
-
-		}else if(($pos=strpos($line, "alias")) !== false)
-		{
-			$domain = trim(substr($line, $pos+5));
-
-		}else if(($pos=strpos($line, "username")) !== false)
-		{
-			$uname = trim(substr($line, $pos+8));
-
-		}else if(($pos=strpos($line, "password")) !== false)
-		{
-			$upwd = trim(substr($line, $pos+8));
-
-		}else if(($pos=strpos($line, "update_period_sec")) !== false)
-		{
-			$period = trim(substr($line, $pos+17));
-		}
-	}
-
-	//check Start sh in "/etc/init.d/"
-	if(file_exists("/etc/init.d/S" .CommonData::$DDNS_RUN_SCRIPT))
-		$enable="enable";
-	else
-		$enable="disable";
-}
-
-//== set DDNS configure
-function setddnsCfg($server, $domain, $uname, $upwd, $period, $enable)
-{
-	$data=file_get_contents(CommonData::$DDNS_SETTING_FILE);
-	$array_data=explode("\n",$data);
-
-	foreach ($array_data as $index =>$line)
-	{
-		$line=trim($line);
-		if($line[0]=='#') continue;
-
-		if(strpos($line, "dyndns_system") !== false)
-		{
-			$line = "dyndns_system " .$server;
-			$array_data[$index] = $line;
-
-		}else if(($pos=strpos($line, "alias")) !== false)
-		{
-			$line = "alias " .$domain;
-			$array_data[$index] = $line;
-
-		}else if(($pos=strpos($line, "username")) !== false)
-		{
-			$line = "username " .$uname;
-			$array_data[$index] = $line;
-
-		}else if(($pos=strpos($line, "password")) !== false)
-		{
-			$line = "password " .$upwd;
-			$array_data[$index] = $line;
-
-		}else if(($pos=strpos($line, "update_period_sec")) !== false)
-		{
-			$line = "update_period_sec " .$period;
-			$array_data[$index] = $line;
-		}
-	}
-
-	$data=implode("\n", $array_data);
-	file_put_contents(CommonData::$DDNS_SETTING_FILE, $data);
-
-	//set Start sh in "/etc/init.d/"
-	if($enable=="enable")
-	{
-		if(!file_exists("/etc/init.d/S" .CommonData::$DDNS_RUN_SCRIPT))
-		{
-			rename("/etc/init.d/K" .CommonData::$DDNS_RUN_SCRIPT, "/etc/init.d/S" .CommonData::$DDNS_RUN_SCRIPT);
-		}
-	}else
-	{
-		if(file_exists("/etc/init.d/S" .CommonData::$DDNS_RUN_SCRIPT))
-		{
-			rename("/etc/init.d/S" .CommonData::$DDNS_RUN_SCRIPT, "/etc/init.d/K" .CommonData::$DDNS_RUN_SCRIPT);
-		}
-	}
-}
 
 //== gety Net Information
 function getNetInfo(&$net_info)
@@ -724,11 +563,7 @@ function getSysInfo(&$sysInfo)
 	$info = file_get_contents(CommonData::$OS_VER_FILE);
 	$info = strstr($info, ":");
 	$sysInfo["os_ver"] = trim($info, ": ");
-/*	compiler product automatically
-	$cmd = CommonData::$OS_VER;
-	$info = shell_exec($cmd);
-	$sysInfo["os_ver"] = trim($info);
-*/
+
 }
 
 //== get storage information
@@ -1190,6 +1025,7 @@ function addUserProc($name, $start, $stop, $exec, $autorun)
 	file_put_contents(CommonData::$USERPROC_FILE, $new_info);
 }
 
+
 //== set autorun User process configure
 //	auto-run proc_list:
 //		[start command]
@@ -1432,6 +1268,131 @@ function setRebootTimerInfo($interval)
 	file_put_contents(CommonData::$REBOOTT_CONFIG, $data);
 }
 
+//============================
+//==== WDT Refresh manage ====
+//============================
+//== get information
+function getWdtRefreshInfo(&$enable, &$alive, &$version)
+{
+	//--check if rebootTimer.exe is enable
+	$proc_name = CommonData::$WDTREFRESH_EXE;
+	$full_file_name = CommonData::$WDTREFRESH_DIR ."/" .$proc_name;
+	getUserProcCgf($proc_list);
+	$n = count($proc_list);
+	for($i=0; $i<$n; $i++)
+	{
+		if($proc_list[$i]["exec"] == $full_file_name)
+		{
+			$enable = $proc_list[$i]["autorun"];
+			$alive = $proc_list[$i]["running"];
+			break;
+		}
+	}
+	//- get version
+	$version = shell_exec($full_file_name ." --ver");
+	$array_data = explode("=", $version);
+	$version = trim($array_data[1]);
+}
+
+//== set wdt process ON/OFF
+function wdtOnOff($enable)
+{
+	//-- auto-run manage
+	if($enable=="enable")
+		$enable="enable";
+	else
+		$enable="disable";
+
+	$proc_name = CommonData::$WDTREFRESH_EXE;
+	$full_file_name = CommonData::$WDTREFRESH_DIR ."/" .$proc_name;
+	//- php call php-script時，需要把「輸入/輸出」重導到別的地方，不可用std io，否則不會執行成功
+	addUserProc("WDT Refresh", $full_file_name ." > /dev/null", CommonData::$WDTREFRESH_DIR ."/kill_wdtRefresh.sh", $full_file_name, $enable);
+	getUserProcCgf($proc_list);
+	setAutoRunFW($proc_list);
+
+	//-- Start/Stop firmware
+	$n = count($proc_list);
+	for($i=0; $i<$n; $i++)
+	{
+		if($proc_list[$i]["exec"] == $full_file_name)
+		{
+			//enable--> restart FW
+			if($enable=="enable")
+			{
+				shell_exec($proc_list[$i]["stop"]);
+				pclose(popen($proc_list[$i]["start"] ." &", "r"));//put into backgroud, or php will be block
+				break;
+			}else
+			{
+				shell_exec($proc_list[$i]["stop"]);
+				break;
+			}
+		}
+	}
+}
+
+//==========================
+//==== NTP / Time Setting
+//==========================
+
+//== get system information
+function getNtpcInfo(&$serverIP, &$retryInterval, &$timezone, &$enable, &$alive, &$version)
+{
+	$IsObject=false;
+	$retryInterval = 3600;//default value
+	$data=file_get_contents(CommonData::$NTPC_CONFIG);
+	$array_data=explode("\n",$data);
+
+	foreach ($array_data as $index =>$line)
+	{
+		$line=trim($line);
+
+		if($line[0]=='#') continue;
+
+		list($name , $value)=split('=' , $line);
+		if($name == "serverIP"){
+			$serverIP = $value;
+		}else if($name == "interval")
+		{
+			$retryInterval = (int)$value;
+		}else if($name == "timezone")
+		{
+			$timezone = $value;
+		}
+	}
+
+	//--check if vxsc.exe is enable
+	$proc_name = CommonData::$NTPC_EXE;
+	$full_file_name = CommonData::$NTPC_DIR ."/" .$proc_name;
+	getUserProcCgf($proc_list);
+	$n = count($proc_list);
+	for($i=0; $i<$n; $i++)
+	{
+		if($proc_list[$i]["exec"] == $full_file_name)
+		{
+			$enable = $proc_list[$i]["autorun"];
+			$alive = $proc_list[$i]["running"];
+			break;
+		}
+	}
+
+	//- get version
+	$version = shell_exec($full_file_name ." --ver");
+	$array_data = explode("=", $version);
+	$version = trim($array_data[1]);
+}
+
+//== set system information
+function setNtpcInfo($serverIP, $retryInterval, $timezone)
+{
+	$data="";
+	$data = $data ."serverIP=" .$serverIP ."\n";
+	$data = $data ."interval=" .$retryInterval ."\n";
+	$data = $data ."timezone=" .$timezone ."\n";
+	file_put_contents(CommonData::$NTPC_CONFIG, $data);
+}
+
+
 //==========================
 //==== password manager ====
 //==========================
@@ -1496,6 +1457,7 @@ function tarWebConfig()
 					."/icpdas/user_proc/* "
 					."/icpdas/vxsc/vxserver.ini "
 					."/icpdas/rebootTimer/rebootTimer.ini "
+					."/icpdas/rtuc/rtuc.ini "
 ;
 
 	$cmd .= $exportFiles;
