@@ -1,4 +1,4 @@
-/icpdas/vxsc/wdt_proc.exe 2
+/icpdas/bin/wdt_proc.exe 2
 echo "kill vxsc.exe"
 /usr/bin/killall -9 vxsc.exe
 /icpdas/bin/wdt_proc.exe 0
